Structs
- Json
Writer - Wraps a
std::io::Writeobject to writeclogoutput in a JSON format - Markdown
Writer - Wraps a
std::io::Writeobject to writeclogoutput in a Markdown format
Enums
Traits
- Format
Writer - A trait that allows writing the results of a
clogrun which can then be written in an arbitrary format. The single required functionwrite_changelog()accepts aclog::SectionMapwhich can be thought of similiar to aclog“AST” of sorts.